searchData={"items":[{"type":"module","title":"BroadwaySQS.ExAwsClient","doc":"Default SQS client used by `BroadwaySQS.Producer` to communicate with AWS\nSQS service.\n\nThis client uses the `ExAws.SQS` library and implements the\n`BroadwaySQS.SQSClient` and `Broadway.Acknowledger` behaviours which define\ncallbacks for receiving and acknowledging messages.","ref":"BroadwaySQS.ExAwsClient.html"},{"type":"module","title":"BroadwaySQS.Producer","doc":"A GenStage producer that continuously polls messages from a SQS queue and\nacknowledge them after being successfully processed.\n\nBy default this producer uses `BroadwaySQS.ExAwsClient` to talk to SQS but\nyou can provide your client by implementing the `BroadwaySQS.SQSClient`\nbehaviour.\n\nFor a quick getting started on using Broadway with Amazon SQS, please see\nthe [Amazon SQS Guide](https://hexdocs.pm/broadway/amazon-sqs.html).","ref":"BroadwaySQS.Producer.html"},{"type":"module","title":"Options - BroadwaySQS.Producer","doc":"Aside from `:receive_interval` and `:sqs_client` which are generic and apply to all\nproducers (regardless of the client implementation), all other options are specific to\nthe `BroadwaySQS.ExAwsClient`, which is the default client.\n\n* `:queue_url` - Required. The url for the SQS queue. *Note this does not have to be a\n  regional endpoint*. For example, `https://sqs.amazonaws.com/0000000000/my_queue`.\n\n* `:sqs_client` - A module that implements the `BroadwaySQS.SQSClient`\n  behaviour. This module is responsible for fetching and acknowledging the\n  messages. Pay attention that all options passed to the producer will be forwarded\n  to the client. The default value is `BroadwaySQS.ExAwsClient`.\n\n* `:receive_interval` (`t:non_neg_integer/0`) - The duration (in milliseconds) for which the producer\n  waits before making a request for more messages. The default value is `5000`.\n\n* `:on_success` (`t:atom/0`) - configures the acking behaviour for successful messages. See the\n  \"Acknowledgments\" section below for all the possible values. The default value is `:ack`.\n\n* `:on_failure` (`t:atom/0`) - configures the acking behaviour for failed messages. See the\n  \"Acknowledgments\" section below for all the possible values. The default value is `:noop`.\n\n* `:config` (`t:keyword/0`) - A set of options that overrides the default ExAws configuration\n  options. The most commonly used options are: `:access_key_id`, `:secret_access_key`,\n  `:scheme`, `:region` and `:port`. For a complete list of configuration options and\n  their default values, please see the `ExAws` documentation. The default value is `[]`.\n\n* `:max_number_of_messages` - The maximum number of messages to be fetched\n  per request. This value must be between `1` and `10`, which is the maximum number\n  allowed by AWS. The default value is `10`.\n\n* `:wait_time_seconds` - The duration (in seconds) for which the call waits\n  for a message to arrive in the queue before returning. This value must be\n  between `0` and `20`, which is the maximum number allowed by AWS. For more\n  information see [\"WaitTimeSeconds\" on the Amazon SQS documentation](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_ReceiveMessage.html).\n\n* `:visibility_timeout` - The time period (in seconds) that a message will\n  remain _invisible_ to other consumers whilst still on the queue and not acknowledged.\n  This is passed to SQS when the message (or messages) are read.\n  This value must be between 0 and 43200 (12 hours).\n\n* `:attribute_names` - A list containing the names of attributes that should be\n  attached to the response and appended to the `metadata`\n  field of the message. You can also use `:all` instead of\n  a list if you want to retrieve all attributes. Supported\n  values are:\n\n      * `:sender_id`\n      * `:sent_timestamp`\n      * `:approximate_receive_count`\n      * `:approximate_first_receive_timestamp`\n      * `:sequence_number`\n      * `:message_deduplication_id`\n      * `:message_group_id`\n      * `:aws_trace_header`\n\n* `:message_attribute_names` - A list containing the names of custom message attributes\n  that should be attached to the response and appended to the `metadata` field of the\n  message. Wildcards `[\".*\"]` and prefixes `[\"bar.*\"]` will retrieve multiple fields.\n  You can also use `:all` instead of the list if you want to retrieve all attributes.","ref":"BroadwaySQS.Producer.html#module-options"},{"type":"module","title":"Acknowledgments - BroadwaySQS.Producer","doc":"You can use the `:on_success` and `:on_failure` options to control how messages are\nacked on SQS. You can set these options when starting the SQS producer or change them\nfor each message through `Broadway.Message.configure_ack/2`. By default, successful\nmessages are acked (`:ack`) and failed messages are not (`:noop`).\n\nThe possible values for `:on_success` and `:on_failure` are:\n\n  * `:ack` - acknowledge the message. SQS will delete the message from the queue\n    and will not redeliver it to any other consumer.\n\n  * `:noop` - do not acknowledge the message. SQS will eventually redeliver the message\n  or remove it based on the \"Visibility Timeout\" and \"Max Receive Count\"\n  configurations. For more information, see:\n\n    * [\"Visibility Timeout\" page on Amazon SQS](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-visibility-timeout.html)\n    * [\"Dead Letter Queue\" page on Amazon SQS](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-dead-letter-queues.html)","ref":"BroadwaySQS.Producer.html#module-acknowledgments"},{"type":"module","title":"Batching - BroadwaySQS.Producer","doc":"Even if you are not interested in working with Broadway batches via the\n`handle_batch/3` callback, we recommend all Broadway pipelines with SQS\nproducers to define a default batcher with `batch_size` set to 10, so\nmessages can be acknowledged in batches, which improves the performance\nand reduce the costs of integrating with SQS.","ref":"BroadwaySQS.Producer.html#module-batching"},{"type":"module","title":"Example - BroadwaySQS.Producer","doc":"Broadway.start_link(MyBroadway,\n      name: MyBroadway,\n      producer: [\n        module: {BroadwaySQS.Producer,\n          queue_url: \"https://sqs.amazonaws.com/0000000000/my_queue\",\n          config: [\n            access_key_id: \"YOUR_AWS_ACCESS_KEY_ID\",\n            secret_access_key: \"YOUR_AWS_SECRET_ACCESS_KEY\",\n            region: \"us-east-2\"\n          ]\n        }\n      ],\n      processors: [\n        default: []\n      ],\n      batchers: [\n        default: [\n          batch_size: 10,\n          batch_timeout: 2000\n        ]\n      ]\n    )\n\nThe above configuration will set up a producer that continuously receives\nmessages from `\"my_queue\"` and sends them downstream.","ref":"BroadwaySQS.Producer.html#module-example"},{"type":"module","title":"Retrieving Metadata - BroadwaySQS.Producer","doc":"By default the following information is added to the `metadata` field in the\n`%Message{}` struct:\n\n  * `message_id` - The message id received when the message was sent to the queue\n  * `receipt_handle` - The receipt handle\n  * `md5_of_body` - An MD5 digest of the message body\n\nYou can access any of that information directly while processing the message:\n\n    def handle_message(_, message, _) do\n      receipt = %{\n        id: message.metadata.message_id,\n        receipt_handle: message.metadata.receipt_handle\n      }\n\n      # Do something with the receipt\n    end\n\nIf you want to retrieve `attributes` or `message_attributes`, you need to\nconfigure the `:attributes_names` and `:message_attributes_names` options\naccordingly, otherwise, attributes will not be attached to the response and\nwill not be available in the `metadata` field\n\n    producer: [\n      module: {BroadwaySQS.Producer,\n        queue_url: \"https://sqs.amazonaws.com/0000000000/my_queue\",\n        # Define which attributes/message_attributes you want to be attached\n        attribute_names: [:approximate_receive_count],\n        message_attribute_names: [\"SomeAttribute\"]\n      }\n    ]\n\nand then in `handle_message`:\n\n    def handle_message(_, message, _) do\n      approximate_receive_count = message.metadata.attributes[\"approximate_receive_count\"]\n      some_attribute = message.metadata.message_attributes[\"SomeAttribute\"]\n\n      # Do something with the attributes\n    end\n\nFor more information on the `:attributes_names` and `:message_attributes_names`\noptions, see [\"AttributeName.N\" and \"MessageAttributeName.N\" on the ReceiveMessage documentation](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_ReceiveMessage.html)","ref":"BroadwaySQS.Producer.html#module-retrieving-metadata"},{"type":"module","title":"Telemetry - BroadwaySQS.Producer","doc":"This library exposes the following Telemetry events:\n\n  * `[:broadway_sqs, :receive_messages, :start]` - Dispatched before receiving\n    messages from SQS (`c:BroadwaySQS.SQSClient.receive_messages/2`)\n\n    * measurement: `%{time: System.monotonic_time}`\n    * metadata: `%{name: atom, demand: integer}`\n\n  * `[:broadway_sqs, :receive_messages, :stop]` - Dispatched after messages have\n    been received from SQS and \"wrapped\".\n\n    * measurement: `%{duration: native_time}`\n    * metadata:\n\n      ```\n      %{\n        name: atom,\n        messages: [Broadway.Message.t],\n        demand: integer\n      }\n      ```\n\n  * `[:broadway_sqs, :receive_messages, :exception]` - Dispatched after a failure\n    while receiving messages from SQS.\n\n    * measurement: `%{duration: native_time}`\n    * metadata:\n\n      ```\n      %{\n        name: atom,\n        demand: integer,\n        kind: kind,\n        reason: reason,\n        stacktrace: stacktrace\n      }\n      ```","ref":"BroadwaySQS.Producer.html#module-telemetry"},{"type":"behaviour","title":"BroadwaySQS.SQSClient","doc":"A generic behaviour to implement SQS Clients for `BroadwaySQS.Producer`.\n\nThis module defines callbacks to normalize options and receive message\nfrom a SQS queue. Modules that implement this behaviour should be passed\nas the `:sqs_client` option from `BroadwaySQS.Producer`.","ref":"BroadwaySQS.SQSClient.html"},{"type":"callback","title":"BroadwaySQS.SQSClient.init/1","doc":"Should initialize the SQS client.\n\nThis callback is called when the producer is started. It should return\n`{:ok, normalized_opts}` if the client was initialized successfully or\n`{:error, reason}` if there was an error. `normalized_opts` is what gets\npassed to the `c:receive_messages/2` callback.","ref":"BroadwaySQS.SQSClient.html#c:init/1"},{"type":"callback","title":"BroadwaySQS.SQSClient.receive_messages/2","doc":"Should fetch messages from the configured SQS queue.\n\n`opts` is the normalized options returned from `c:init/1`. The `demand`\nargument is the number of messages that the producer is asking for.","ref":"BroadwaySQS.SQSClient.html#c:receive_messages/2"},{"type":"type","title":"BroadwaySQS.SQSClient.messages/0","doc":"","ref":"BroadwaySQS.SQSClient.html#t:messages/0"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,49]},"content_type":"text/markdown"}